@@ -2,6 +2,10 @@
 
 __author__ = """Dan Lykov"""
 __email__ = 'lkv97dn@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 from pyrofiler.threaded import threaded
+from pyrofiler.profilers import (
+    timing, timed
+    , cpu_util, mem_util, proc_count
+)
